@@ -431,9 +431,10 @@ def start_server():
     access_file_handler = logging.FileHandler(ACCESS_LOG_FILE)
     access_file_handler.setFormatter(formatter)
     access_logger.addHandler(access_file_handler)
-    
-    app.listen(10101)
-
+    try:
+        app.listen(10101)
+    except OSError:
+        raise Exception
     return app
 
 
